@@ -3,7 +3,7 @@ package DBIx::Diff::Schema;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-23'; # DATE
 our $DIST = 'DBIx-Diff-Schema'; # DIST
-our $VERSION = '0.095'; # VERSION
+our $VERSION = '0.096'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -274,8 +274,11 @@ sub list_indexes {
                 push @res, $hashes[0];
             } else {
                 my %merged_hash;
-                $merged_hash{columns} = [map { $_->{COLUMN_NAME} } @hashes];
-                for my $hash (@hashes) { for (keys %$hash) { $merged_hash{$_} = $hash->{$_} } }
+                $merged_hash{columns} = [];
+                for my $hash (@hashes) {
+                    $merged_hash{columns}[ $hash->{ORDINAL_POSITION}-1 ] = $hash->{COLUMN_NAME};
+                    for (keys %$hash) { $merged_hash{$_} = $hash->{$_} }
+                }
                 delete $merged_hash{ORDINAL_POSITION};
                 push @res, \%merged_hash;
             }
@@ -568,7 +571,7 @@ DBIx::Diff::Schema - Compare schema of two DBI databases
 
 =head1 VERSION
 
-This document describes version 0.095 of DBIx::Diff::Schema (from Perl distribution DBIx-Diff-Schema), released on 2020-04-23.
+This document describes version 0.096 of DBIx::Diff::Schema (from Perl distribution DBIx-Diff-Schema), released on 2020-04-23.
 
 =head1 SYNOPSIS
 
